@@ -4,14 +4,17 @@
 
 """
 
-__all__ = ['load', 'register', 'Factory',
-           'Validator', 'ReferenceValidator', 'Draft04Validator',
-           'CompilationError', 'ReferenceError', 'ValidationError']
+__all__ = ['load', 'register', 'Factory', 'Context',
+           'Validator', 'ReferenceValidator',
+           'Draft03Validator', 'Draft04Validator',
+           'error', 'CompilationError', 'ReferenceError', 'ValidationError']
 
 from .bases import Validator, ReferenceValidator
-from .exceptions import error, CompilationError, ReferenceError, ValidationError
+from .exceptions import error, CompilationError, ReferenceError, ValidationError  # noqa
 from .factorize import register, Factory, Context
 from . import draft04  # noqa
+from . import draft03  # noqa
+from .draft03 import Draft03Validator  # noqa
 from .draft04 import Draft04Validator  # noqa
 
 
