@@ -11,9 +11,6 @@ from jsonspec.validators import load, ValidationError, CompilationError
 from jsonspec.reference.providers import SpecProvider, ProxyProvider
 from jsonspec import driver as json
 
-# from jsonspec.validators.exceptions import ValidationError
-from . import TestCase
-
 import io
 import os
 import pytest
@@ -42,8 +39,11 @@ for data, src in contents('remotes'):
 
 def scenarios(draft):
     for data, src in contents('tests', draft):
-        if PY2 and src in ('minLength.json', 'maxLength.json'):
+        skip = []
+        if PY2:
             # json module cannot handle well unicode strings
+            skip.extend(('minLength.json', 'maxLength.json'))
+        if src in skip:
             continue
 
         for block in data:
@@ -60,4 +60,4 @@ def test_common(schema, description, data, valid, src):
     except (ValidationError, CompilationError) as error:
         if valid:
             logger.exception(error)
-            assert False, description
\ No newline at end of file
+            assert False, description
